summaryrefslogtreecommitdiff
path: root/proto/static/static.h
diff options
context:
space:
mode:
Diffstat (limited to 'proto/static/static.h')
-rw-r--r--proto/static/static.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/proto/static/static.h b/proto/static/static.h
index a0a95a4b..edd2dc22 100644
--- a/proto/static/static.h
+++ b/proto/static/static.h
@@ -50,7 +50,10 @@ struct static_route {
byte use_bfd; /* Configured to use BFD */
uint mpls_label; /* Local MPLS label, -1 if unused */
struct bfd_request *bfd_req; /* BFD request, if BFD is used */
- mpls_label_stack *mls; /* MPLS label stack; may be NULL */
+ union {
+ mpls_label_stack *mls; /* MPLS label stack; may be NULL */
+ adata *aspa; /* ASPA provider list; may be NULL */
+ };
};
/*